Description: The International Journal of Computer Science: Theory and Application is an open access and peer-reviewed Journal. Authors are invited to submit original papers on both applied or/and theoretical aspects of computer science.
Keywords: International Journal of Computer Science; Journal of Computer Science; Call For Papers in Computer Science; Open Access Journal; Research Papers Publication.

International Journal of Computer Science

#

## Search

Search for |

Additional Search Options (click to show) Additional Search Options (click to hide)

#### Search categories
Authors |
Title |
Abstract |
Full Text |
Supplementary File(s) |
#### Publication Date
From |
Until |
#### Index terms
Discipline(s) |
Keyword(s) |
Type (method/approach) |
Coverage |
All index term fields |

Issue | Title
No Results

Search tips:

- Search terms are case-insensitive
- Common words are ignored
- By default only articles containing all terms in the query are returned (i.e., AND is implied)
- Combine multiple words with OR to find articles containing either term; e.g., education OR research
- Use parentheses to create more complex queries; e.g., archive ((journal OR conference) NOT theses)
- Search for an exact phrase by putting it in quotes; e.g., "open access publishing"
- Exclude a word by prefixing it with - or NOT; e.g. online -politics or online NOT politics
- Use * in a term as a wildcard to match any sequence of characters; e.g., soci* morality would match documents containing "sociological" or "societal"

ISSN: 2336-0984